// Global variables
var OFE_imagePattern = /^.*\.(gif|jpe?g|png)$/i;
var OFE_urlPattern = /http:\/\/([^.]+\.){2,}.*/i;
var OFE_prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);

// Add a listener that will parse a page when it is loaded if the flag is set
window.addEventListener("load", function() { OFE_outFoxEmPageLoad.init(); }, false);

var OFE_outFoxEmPageLoad = {
	init: function() {
		var appcontent = document.getElementById("appcontent");   // browser
		if(appcontent) {
			appcontent.addEventListener("load", this.onPageLoad, true);
		}
  	},

	onPageLoad: function(aEvent) {
		var doc = aEvent.originalTarget;
		var outFoxEmOn = OFE_prefs.getBoolPref("outfoxem.enabled");
		
		// If the preference is set to true and the doc being
		// loaded is not an image, parse the page.
		if (outFoxEmOn && !doc.URL.match(OFE_imagePattern)) {
			try {
				OFE_parsePage(doc);
			} catch (e) {
				var newPage = '<html><head><title>Unable to OutFoxEm!</title></head>';
				newPage += '<body><h3>Unable to OutFoxEm!</h3>';
				newPage += '<p><strong>Please cut and paste the following information below and <a href="mailto:sprak3000@gmail.com?subject=OutFoxEm Report">email it</a> to the author:</strong></p>';
				newPage += '<p>Page URL:<br />' + doc.URL + '</p><p>Error Message:<br />' + e + '</p>';
				newPage += '</body></html>';

				doc.open();
				doc.write(newPage);
				doc.close();
			}
		}
  	}
}

// Event Listener that determines if the popup menu is for right-clicking on a link.
// If so, display our option.
function OFE_outfoxemContext()
{
	var menuitem = document.getElementById("context-outfoxem");
	if (menuitem) {
		menuitem.hidden = gContextMenu.onLink;
	}
}

// Initialize the application; add menu event listener to determine when to show menu option.
function OFE_outfoxemInit()
{
	var menu = document.getElementById("contentAreaContextMenu");
  	menu.addEventListener("popupshowing", OFE_outfoxemContext, false);

	var on = false;

	// If the preference does not exist, set it to false
	if (OFE_prefs.getPrefType("outfoxem.enabled") != OFE_prefs.PREF_BOOL) {
		OFE_prefs.setBoolPref("outfoxem.enabled", false);
	} else {
		on = OFE_prefs.getBoolPref("outfoxem.enabled");
	}

	var button = document.getElementById("outfoxem-button");
	button.checked = on;
}

// Parse out all img tags that are contained by an a tag
// that has its href attribute pointing to an image.
function OFE_parsePage(doc)
{
	// First, turn off all images. 
	var documentImages = doc.getElementsByTagName("img");
	var documentImagesCount = documentImages.length;

	for (i = 0; i < documentImagesCount; i++) {
		documentImages[i].style.display = "none";
	}
	
	// Grab all links (<a> tags) from the document.
	var links = doc.getElementsByTagName("a");
	var linksCount = links.length;

	// Iterate over the links in a document and parse out those linking directly to an image file.
	for (i = 0; i < linksCount; i++) {
		var currentLink = links[i];

		/**
		  * If the current <a> tag has an href attribute and that attribute value
		  * matches the image pattern, grab the values of the tags and add them
		  * to the new HTML document to display.
		  */
		if (currentLink.hasAttribute("href") &&
			currentLink.getAttribute("href").match(OFE_imagePattern) != null) {

			currentLink.style.display = "inline";

			// Grab all <img> tags under the <a> tag and parse them.
			var imgChildren = currentLink.getElementsByTagName("img");
			var imgChildrenCount = imgChildren.length;

			for (j = 0; j < imgChildrenCount; j++) {
				if (imgChildren[j].hasAttribute("src")) {
					imgChildren[j].style.display = "inline";
				}
			}
		} else {
			currentLink.style.display = "none";
		}
	}
}

// Main function
function OFE_outFoxEm()
{
	var outFoxEmOn = OFE_prefs.getBoolPref("outfoxem.enabled");

	if (outFoxEmOn) {
		OFE_prefs.setBoolPref("outfoxem.enabled", false);
	} else {
		OFE_prefs.setBoolPref("outfoxem.enabled", true);
	}
}
